package org.apache.commons.collections4.iterators;

import java.util.HashSet;
import java.util.Map;
import org.apache.commons.collections4.MapIterator;
import java.util.NoSuchElementException;
import java.util.Set;
import org.junit.Test;

/** 
 * Abstract class for testing the MapIterator interface.
 * <p>
 * This class provides a framework for testing an implementation of MapIterator.
 * Concrete subclasses must provide the list iterator to be tested.
 * They must also specify certain details of how the list iterator operates by
 * overriding the supportsXxx() methods if necessary.
 * 
 * @since 3.0
 * @version $Id$
 */
public abstract class AbstractMapIteratorTest<K, V> extends AbstractIteratorTest<K> {
    /** 
     * JUnit constructor.
     * 
     * @param testName  the test class name
     */
public AbstractMapIteratorTest(final String testName) {
        super(testName);
    }

    /** 
     * Implement this method to return a map iterator over an empty map.
     * 
     * @return an empty iterator
     */
@Override
    public abstract MapIterator<K, V> makeEmptyIterator();

    /** 
     * Implement this method to return a map iterator over a map with elements.
     * 
     * @return a full iterator
     */
@Override
    public abstract MapIterator<K, V> makeObject();

    /** 
     * Implement this method to return the map which contains the same data as the
     * iterator.
     * 
     * @return a full map which can be updated
     */
public abstract Map<K, V> getMap();

    /** 
     * Implement this method to return the confirmed map which contains the same
     * data as the iterator.
     * 
     * @return a full map which can be updated
     */
public abstract Map<K, V> getConfirmedMap();

    /** 
     * Whether or not we are testing an iterator that supports setValue().
     * Default is true.
     * 
     * @return true if Iterator supports set
     */
public boolean supportsSetValue() {
        return true;
    }

    /** 
     * Whether the get operation on the map structurally modifies the map,
     * such as with LRUMap. Default is false.
     * 
     * @return true if the get method structurally modifies the map
     */
public boolean isGetStructuralModify() {
        return false;
    }

    /** 
     * The values to be used in the add and set tests.
     * Default is two strings.
     */
@SuppressWarnings(value = "unchecked")
    public V[] addSetValues() {
        return ((V[])(new Object[]{ "A" , "B" }));
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testEmptyMapIterator_add196() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_add196");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testEmptyMapIterator_add197() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_add197");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testEmptyMapIterator_add198() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_add198");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testEmptyMapIterator_add199() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_add199");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[0]);
                    it.setValue(addSetValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testEmptyMapIterator_add200() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_add200");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[0]);
                    it.setValue(addSetValues()[0]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
public void testEmptyMapIterator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[1]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
public void testEmptyMapIterator_literalMutation216() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_literalMutation216");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[-1]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
public void testEmptyMapIterator_literalMutation217() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_literalMutation217");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
public void testEmptyMapIterator_literalMutation219() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_literalMutation219");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[1]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
public void testEmptyMapIterator_literalMutation220() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_literalMutation220");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[-1]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the empty list iterator contract is correct.
     */
public void testEmptyMapIterator_literalMutation221() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapIterator_literalMutation221");
            if (!(supportsEmptyIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeEmptyIterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,it);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,it.hasNext());
            try {
                it.next();
            } catch (final NoSuchElementException ex) {
            }
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            if (!(supportsSetValue())) {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final UnsupportedOperationException ex) {
                } catch (final IllegalStateException ex) {
                }
            } else {
                try {
                    it.setValue(addSetValues()[0]);
                } catch (final IllegalStateException ex) {
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that the full list iterator contract is correct.
     */
@Test(timeout = 1000)
    public void testFullMapIterator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFullMapIterator");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),466,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),467,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),457,it.hasNext());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),458,it.hasNext());
            final Set<K> set = new HashSet<K>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),468,set);
            while (it.hasNext()) {
                final K key = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),469,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,key);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,it.getKey());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,map.containsKey(key));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),462,set.add(key));
                final V value = it.getValue();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),470,value);
                if (!(isGetStructuralModify())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),463,map.get(key));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),464,value);
                } 
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),465,map.containsValue(value));
                verify();
                verify();
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_add212() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_add212");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_add213() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_add213");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_add214() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_add214");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_add215() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_add215");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_add216() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_add216");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_add217() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_add217");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_add218() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_add218");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_add219() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_add219");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_add220() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_add220");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation224() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation224");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[-1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation225() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation225");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation227() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation227");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 2 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation228() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation228");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 0 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation229() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation229");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 0 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation231() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation231");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[1] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation232() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation232");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[-1] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation233() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation233");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation235() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation235");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[2];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation236() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation236");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSet_literalMutation237() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_literalMutation237");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_remove161() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_remove161");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_remove162() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_remove162");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_remove163() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_remove163");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_remove164() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_remove164");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_remove165() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_remove165");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_remove166() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_remove166");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_remove167() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_remove167");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            verify();
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSet_remove168() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSet_remove168");
            if (!(supportsFullIterator())) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,newValue);
            final V newValue2 = (addSetValues().length) == 1 ? addSetValues()[0] : addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,newValue2);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,key);
            final V value = it.getValue();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,value);
            if (!(supportsSetValue())) {
                try {
                    it.setValue(newValue);
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            final V old = it.setValue(newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,old);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,it.getValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,old);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,map.containsKey(key));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,confirmed.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,map.containsValue(old));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,map.containsValue(newValue));
            it.setValue(newValue);
            confirmed.put(key, newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,newValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,it.getValue());
            verify();
            it.setValue(newValue2);
            confirmed.put(key, newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,it.getKey());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,newValue2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,it.getValue());
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Override
    public void testRemove() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.remove();
            confirmed.remove(key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            verify();
            try {
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_add227() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_add227");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.remove();
            confirmed.remove(key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            verify();
            try {
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_add228() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_add228");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.remove();
            it.remove();
            confirmed.remove(key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            verify();
            try {
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_add229() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_add229");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.remove();
            confirmed.remove(key);
            confirmed.remove(key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            verify();
            try {
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_add230() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_add230");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.remove();
            confirmed.remove(key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            verify();
            verify();
            try {
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_add231() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_add231");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.remove();
            confirmed.remove(key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            verify();
            try {
                it.remove();
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_add232() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_add232");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.remove();
            confirmed.remove(key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            verify();
            try {
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_remove174() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_remove174");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            confirmed.remove(key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            verify();
            try {
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_remove175() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_remove175");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.remove();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            verify();
            try {
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_remove176() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_remove176");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.remove();
            confirmed.remove(key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            try {
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testRemove_remove177() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemove_remove177");
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,it);
            final Map<K, V> map = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,map);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,key);
            if (!(supportsRemove())) {
                try {
                    it.remove();
                } catch (final UnsupportedOperationException ex) {
                }
                return ;
            } 
            it.remove();
            confirmed.remove(key);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,map.containsKey(key));
            try {
                it.remove();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSetRemoveSet() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_add221() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_add221");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_add222() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_add222");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_add223() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_add223");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_add224() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_add224");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            verify();
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_add225() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_add225");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_add226() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_add226");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSetRemoveSet_literalMutation239() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_literalMutation239");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSetRemoveSet_literalMutation240() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_literalMutation240");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[-1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIteratorSetRemoveSet_literalMutation241() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_literalMutation241");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_remove169() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_remove169");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_remove170() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_remove170");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            confirmed.remove(key);
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_remove171() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_remove171");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            verify();
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_remove172() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_remove172");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorSetRemoveSet_remove173() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorSetRemoveSet_remove173");
            if ((!(supportsSetValue())) || (!(supportsRemove()))) {
                return ;
            } 
            final V newValue = addSetValues()[0];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,newValue);
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,key);
            it.setValue(newValue);
            it.remove();
            confirmed.remove(key);
            try {
                it.setValue(newValue);
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetKey() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetKey");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,key);
            it.remove();
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetKey_add203() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetKey_add203");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,key);
            it.remove();
            confirmed.remove(key);
            confirmed.remove(key);
            verify();
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetKey_add204() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetKey_add204");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,key);
            it.remove();
            confirmed.remove(key);
            verify();
            verify();
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetKey_add205() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetKey_add205");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,key);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.getKey();
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetKey_add206() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetKey_add206");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,key);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            verify();
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetKey_remove153() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetKey_remove153");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,key);
            confirmed.remove(key);
            verify();
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetKey_remove154() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetKey_remove154");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,key);
            it.remove();
            verify();
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetKey_remove155() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetKey_remove155");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,key);
            it.remove();
            confirmed.remove(key);
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetKey_remove156() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetKey_remove156");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,key);
            it.remove();
            confirmed.remove(key);
            try {
                it.getKey();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetValue() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetValue");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,key);
            it.remove();
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetValue_add208() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetValue_add208");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,key);
            it.remove();
            confirmed.remove(key);
            confirmed.remove(key);
            verify();
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetValue_add209() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetValue_add209");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,key);
            it.remove();
            confirmed.remove(key);
            verify();
            verify();
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetValue_add210() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetValue_add210");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,key);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.getValue();
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetValue_add211() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetValue_add211");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,key);
            it.remove();
            confirmed.remove(key);
            verify();
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            verify();
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetValue_remove157() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetValue_remove157");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,key);
            confirmed.remove(key);
            verify();
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetValue_remove158() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetValue_remove158");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,key);
            it.remove();
            verify();
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetValue_remove159() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetValue_remove159");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,key);
            it.remove();
            confirmed.remove(key);
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIteratorRemoveGetValue_remove160() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIteratorRemoveGetValue_remove160");
            if (!(supportsRemove())) {
                return ;
            } 
            final MapIterator<K, V> it = makeObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,it);
            final Map<K, V> confirmed = getConfirmedMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,confirmed);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,it.hasNext());
            final K key = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,key);
            it.remove();
            confirmed.remove(key);
            try {
                it.getValue();
            } catch (final IllegalStateException ex) {
            }
            verify();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

