package org.apache.commons.collections4.set;

import org.apache.commons.collections4.collection.AbstractCollectionTest;
import java.util.Collection;
import java.util.HashSet;
import java.util.Set;
import org.junit.Test;

/** 
 * Abstract test class for {@link java.util.Set} methods and contracts.
 * <p>
 * Since {@link java.util.Set} doesn't stipulate much new behavior that isn't already
 * found in {@link java.util.Collection}, this class basically just adds tests for
 * {@link java.util.Set#equals} and {@link java.util.Set#hashCode()} along with an updated
 * {@link #verify()} that ensures elements do not appear more than once in the
 * set.
 * <p>
 * To use, subclass and override the {@link #makeObject()}
 * method.  You may have to override other protected methods if your
 * set is not modifiable, or if your set restricts what kinds of
 * elements may be added; see {@link org.apache.commons.collections4.collection.AbstractCollectionTest} for more details.
 * 
 * @since 3.0
 * @version $Id$
 */
public abstract class AbstractSetTest<E> extends AbstractCollectionTest<E> {
    /** 
     * JUnit constructor.
     * 
     * @param name  name for test
     */
public AbstractSetTest(final String name) {
        super(name);
    }

    /** 
     * Provides additional verifications for sets.
     */
@Override
    public void verify() {
        super.verify();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),967,getConfirmed());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),968,getCollection());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),969,getConfirmed().hashCode());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),970,getCollection().hashCode());
        final Collection<E> set = makeConfirmedCollection();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),972,set);
        for (E element : getCollection()) {
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),971,set.add(element));
        }
    }

    /** 
     * Set equals method is defined.
     */
@Override
    public boolean isEqualsCheckable() {
        return true;
    }

    /** 
     * Returns an empty Set for use in modification testing.
     * 
     * @return a confirmed empty collection
     */
@Override
    public Collection<E> makeConfirmedCollection() {
        return new HashSet<E>();
    }

    /** 
     * Returns a full Set for use in modification testing.
     * 
     * @return a confirmed full collection
     */
@Override
    public Collection<E> makeConfirmedFullCollection() {
        final Collection<E> set = makeConfirmedCollection();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),954,set);
        set.addAll(java.util.Arrays.asList(getFullElements()));
        return set;
    }

    /** 
     * Makes an empty set.  The returned set should have no elements.
     * 
     * @return an empty set
     */
@Override
    public abstract Set<E> makeObject();

    /** 
     * Makes a full set by first creating an empty set and then adding
     * all the elements returned by {@link #getFullElements()}.
     * 
     * Override if your set does not support the add operation.
     * 
     * @return a full set
     */
@Override
    public Set<E> makeFullCollection() {
        final Set<E> set = makeObject();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),955,set);
        set.addAll(java.util.Arrays.asList(getFullElements()));
        return set;
    }

    /** 
     * Return the {@link org.apache.commons.collections4.collection.AbstractCollectionTest#collection} fixture, but cast as a Set.
     */
@Override
    public Set<E> getCollection() {
        return ((Set<E>)(super.getCollection()));
    }

    /** 
     * Return the {@link org.apache.commons.collections4.collection.AbstractCollectionTest#confirmed} fixture, but cast as a Set.
     */
@Override
    public Set<E> getConfirmed() {
        return ((Set<E>)(super.getConfirmed()));
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_add469() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_add469");
            resetEmpty();
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_add470() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_add470");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_add471() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_add471");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_add472() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_add472");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_add473() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_add473");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_add474() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_add474");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_add475() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_add475");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "#nchecked")
    public void testSetEquals() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "uncheck¼ed")
    public void testSetEquals_literalMutation549() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_literalMutation549");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "uncheckd")
    public void testSetEquals_literalMutation550() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_literalMutation550");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    public void testSetEquals_literalMutation551() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_literalMutation551");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)(".oo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    public void testSetEquals_literalMutation552() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_literalMutation552");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("fâoo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    public void testSetEquals_literalMutation553() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_literalMutation553");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("fo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_remove360() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_remove360");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_remove361() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_remove361");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_remove362() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_remove362");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_remove363() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_remove363");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_remove364() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_remove364");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_remove365() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_remove365");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.addAll(java.util.Arrays.asList(getOtherElements()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#equals(Object)}.
     */
@SuppressWarnings(value = "unchecked")
    @Test(timeout = 1000)
    public void testSetEquals_remove366() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetEquals_remove366");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,getConfirmed());
            verify();
            final Collection<E> set2 = makeConfirmedCollection();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,set2);
            set2.add(((E)("foo")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,!(getCollection().equals(set2)));
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,getCollection());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,getConfirmed());
            verify();
            set2.clear();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,!(getCollection().equals(set2)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#hashCode()}.
     */
@Test(timeout = 1000)
    public void testSetHashCode() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetHashCode");
            resetEmpty();
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),963,getCollection().hashCode());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),964,getConfirmed().hashCode());
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),965,getCollection().hashCode());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),966,getConfirmed().hashCode());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#hashCode()}.
     */
@Test(timeout = 1000)
    public void testSetHashCode_add477() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetHashCode_add477");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),963,getCollection().hashCode());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),964,getConfirmed().hashCode());
            resetFull();
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),965,getCollection().hashCode());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),966,getConfirmed().hashCode());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#hashCode()}.
     */
@Test(timeout = 1000)
    public void testSetHashCode_remove367() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetHashCode_remove367");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),963,getCollection().hashCode());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),964,getConfirmed().hashCode());
            resetFull();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),965,getCollection().hashCode());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),966,getConfirmed().hashCode());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests {@link java.util.Set#hashCode()}.
     */
@Test(timeout = 1000)
    public void testSetHashCode_remove368() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetHashCode_remove368");
            resetEmpty();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),963,getCollection().hashCode());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),964,getConfirmed().hashCode());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),965,getCollection().hashCode());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),966,getConfirmed().hashCode());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

