package org.eclipse.jgit.util;


/** 
 * A more efficient List&lt;Integer&gt; using a primitive integer array.
 */
public class IntList {
    private int[] entries;

    private int count;

    /** 
     * Create an empty list with a default capacity.
     */
public IntList() {
        this(10);
    }

    /** 
     * * Create an empty list with the specified capacity.
     * *
     * * @param capacity
     * *            number of entries the list can initially hold.
     */
public IntList(final int capacity) {
        entries = new int[capacity];
    }

    /** 
     * @return number of entries in this list
     */
public int size() {
        return count;
    }

    /** 
     * * @param i
     * *            index to read, must be in the range [0, {@link #size()}).
     * * @return the number at the specified index
     * * @throws ArrayIndexOutOfBoundsException
     * *             the index outside the valid range
     */
public int get(final int i) {
        if ((count) <= i)
            throw new ArrayIndexOutOfBoundsException(i);
        
        return entries[i];
    }

    /** 
     * Empty this list
     */
public void clear() {
        count = 0;
    }

    /** 
     * * Add an entry to the end of the list.
     * *
     * * @param n
     * *            the number to add.
     */
public void add(final int n) {
        if ((count) == (entries.length))
            grow();
        
        entries[(count)++] = n;
    }

    /** 
     * * Assign an entry in the list.
     * *
     * * @param index
     * *            index to set, must be in the range [0, {@link #size()}).
     * * @param n
     * *            value to store at the position.
     */
public void set(final int index, final int n) {
        if ((count) < index)
            throw new ArrayIndexOutOfBoundsException(index);
        else if ((count) == index)
            add(n);
        else
            entries[index] = n;
        
    }

    /** 
     * * Pad the list with entries.
     * *
     * * @param toIndex
     * *            index position to stop filling at. 0 inserts no filler. 1
     * *            ensures the list has a size of 1, adding <code>val</code> if
     * *            the list is currently empty.
     * * @param val
     * *            value to insert into padded positions.
     */
public void fillTo(int toIndex, final int val) {
        while ((count) < toIndex)
            add(val);
    }

    private void grow() {
        final int[] n = new int[(((entries.length) + 16) * 3) / 2];
        java.lang.System.arraycopy(entries, 0, n, 0, count);
        entries = n;
    }

    public String toString() {
        final StringBuilder r = new StringBuilder();
        r.append('[');
        for (int i = 0 ; i < (count) ; i++) {
            if (i > 0)
                r.append(", ");
            
            r.append(entries[i]);
        }
        r.append(']');
        return r.toString();
    }
}

