package org.eclipse.jgit.api;

import java.io.File;
import org.eclipse.jgit.api.errors.GitAPIException;
import java.io.IOException;
import org.eclipse.jgit.api.errors.InvalidRefNameException;
import org.eclipse.jgit.api.errors.JGitInternalException;
import org.eclipse.jgit.internal.JGitText;
import java.util.List;
import org.eclipse.jgit.errors.LockFailedException;
import org.eclipse.jgit.lib.ObjectId;
import org.eclipse.jgit.lib.Ref;
import org.eclipse.jgit.lib.RefUpdate;
import org.eclipse.jgit.lib.ReflogEntry;
import org.eclipse.jgit.lib.ReflogReader;
import org.eclipse.jgit.internal.storage.file.ReflogWriter;
import org.eclipse.jgit.lib.Repository;

/** 
 * Command class to delete a stashed commit reference
 * 
 * @see <a href="http://www.kernel.org/pub/software/scm/git/docs/git-stash.html"
 * >Git documentation about Stash</a>
 * @since 2.0
 */
public class StashDropCommand extends GitCommand<org.eclipse.jgit.lib.ObjectId> {
    private int stashRefEntry;

    private boolean all;

    /** 
     * * @param repo
     */
public StashDropCommand(Repository repo) {
        super(repo);
    }

    /** 
     * * Set the stash reference to drop (0-based).
     * * <p>
     * * This will default to drop the latest stashed commit (stash@{0}) if
     * * unspecified
     * *
     * * @param stashRef
     * * @return {@code this}
     */
public StashDropCommand setStashRef(final int stashRef) {
        if (stashRef < 0)
            throw new IllegalArgumentException();
        
        stashRefEntry = stashRef;
        return this;
    }

    /** 
     * * Set wheter drop all stashed commits
     * *
     * * @param all
     * *            true to drop all stashed commits, false to drop only the
     * *            stashed commit set via calling {@link #setStashRef(int)}
     * * @return {@code this}
     */
public StashDropCommand setAll(final boolean all) {
        this.all = all;
        return this;
    }

    private Ref getRef() throws GitAPIException {
        try {
            return repo.getRef(org.eclipse.jgit.lib.Constants.R_STASH);
        } catch (IOException e) {
            throw new InvalidRefNameException(java.text.MessageFormat.format(JGitText.get().cannotRead, org.eclipse.jgit.lib.Constants.R_STASH) , e);
        }
    }

    private RefUpdate createRefUpdate(final Ref stashRef) throws IOException {
        RefUpdate update = repo.updateRef(org.eclipse.jgit.lib.Constants.R_STASH);
        update.disableRefLog();
        update.setExpectedOldObjectId(stashRef.getObjectId());
        update.setForceUpdate(true);
        return update;
    }

    private void deleteRef(final Ref stashRef) {
        try {
            RefUpdate.Result result = createRefUpdate(stashRef).delete();
            if ((RefUpdate.Result.FORCED) != result)
                throw new JGitInternalException(java.text.MessageFormat.format(JGitText.get().stashDropDeleteRefFailed, result));
            
        } catch (IOException e) {
            throw new JGitInternalException(JGitText.get().stashDropFailed , e);
        }
    }

    private void updateRef(Ref stashRef, ObjectId newId) {
        try {
            RefUpdate update = createRefUpdate(stashRef);
            update.setNewObjectId(newId);
            RefUpdate.Result result = update.update();
            switch (result) {
                case FORCED :
                case NEW :
                case NO_CHANGE :
                    return ;
                default :
                    throw new JGitInternalException(java.text.MessageFormat.format(JGitText.get().updatingRefFailed, org.eclipse.jgit.lib.Constants.R_STASH, newId, result));
            }
        } catch (IOException e) {
            throw new JGitInternalException(JGitText.get().stashDropFailed , e);
        }
    }

    /** 
     * * Drop the configured entry from the stash reflog and return value of the
     * * stash reference after the drop occurs
     * *
     * * @return commit id of stash reference or null if no more stashed changes
     * * @throws GitAPIException
     */
public ObjectId call() throws GitAPIException {
        checkCallable();
        Ref stashRef = getRef();
        if (stashRef == null)
            return null;
        
        if (all) {
            deleteRef(stashRef);
            return null;
        } 
        List<org.eclipse.jgit.lib.ReflogEntry> entries;
        try {
            ReflogReader reader = repo.getReflogReader(org.eclipse.jgit.lib.Constants.R_STASH);
            entries = reader.getReverseEntries();
        } catch (IOException e) {
            throw new JGitInternalException(JGitText.get().stashDropFailed , e);
        }
        if ((stashRefEntry) >= (entries.size()))
            throw new JGitInternalException(JGitText.get().stashDropMissingReflog);
        
        if ((entries.size()) == 1) {
            deleteRef(stashRef);
            return null;
        } 
        ReflogWriter writer = new ReflogWriter(repo , true);
        String stashLockRef = ReflogWriter.refLockFor(org.eclipse.jgit.lib.Constants.R_STASH);
        final File stashLockFile = writer.logFor(stashLockRef);
        File stashFile = writer.logFor(org.eclipse.jgit.lib.Constants.R_STASH);
        if (stashLockFile.exists())
            throw new JGitInternalException(JGitText.get().stashDropFailed , new LockFailedException(stashFile));
        
        entries.remove(stashRefEntry);
        ObjectId entryId = ObjectId.zeroId();
        try {
            for (int i = (entries.size()) - 1 ; i >= 0 ; i--) {
                ReflogEntry entry = entries.get(i);
                writer.log(stashLockRef, entryId, entry.getNewId(), entry.getWho(), entry.getComment());
                entryId = entry.getNewId();
            }
            if (!(stashLockFile.renameTo(stashFile))) {
                org.eclipse.jgit.util.FileUtils.delete(stashFile);
                if (!(stashLockFile.renameTo(stashFile)))
                    throw new JGitInternalException(java.text.MessageFormat.format(JGitText.get().renameFileFailed, stashLockFile.getPath(), stashFile.getPath()));
                
            } 
        } catch (IOException e) {
            throw new JGitInternalException(JGitText.get().stashDropFailed , e);
        }
        updateRef(stashRef, entryId);
        try {
            Ref newStashRef = repo.getRef(org.eclipse.jgit.lib.Constants.R_STASH);
            return newStashRef != null ? newStashRef.getObjectId() : null;
        } catch (IOException e) {
            throw new InvalidRefNameException(java.text.MessageFormat.format(JGitText.get().cannotRead, org.eclipse.jgit.lib.Constants.R_STASH) , e);
        }
    }
}

