package org.eclipse.jgit.internal.storage.file;

import org.eclipse.jgit.lib.AnyObjectId;
import java.util.zip.CRC32;
import org.eclipse.jgit.lib.Constants;
import java.util.zip.Deflater;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import org.eclipse.jgit.internal.JGitText;
import java.util.List;
import org.eclipse.jgit.errors.LockFailedException;
import java.security.MessageDigest;
import org.eclipse.jgit.transport.PackParser;
import org.eclipse.jgit.transport.PackedObjectInfo;
import org.eclipse.jgit.lib.ProgressMonitor;
import java.io.RandomAccessFile;

/** 
 * Consumes a pack stream and stores as a pack file in {@link ObjectDirectory}.
 * <p>
 * To obtain an instance of a parser, applications should use
 * {@link ObjectInserter#newPackParser(InputStream)}.
 */
public class ObjectDirectoryPackParser extends PackParser {
    private final FileObjectDatabase db;

    /** 
     * CRC-32 computation for objects that are appended onto the pack.
     */
private final CRC32 crc;

    /** 
     * Running SHA-1 of any base objects appended after {@link #origEnd}.
     */
private final MessageDigest tailDigest;

    /** 
     * Preferred format version of the pack-*.idx file to generate.
     */
private int indexVersion;

    /** 
     * If true, pack with 0 objects will be stored. Usually these are deleted.
     */
private boolean keepEmpty;

    /** 
     * Path of the temporary file holding the pack data.
     */
private File tmpPack;

    /** 
     * * Path of the index created for the pack, to find objects quickly at read
     * * time.
     */
private File tmpIdx;

    /** 
     * Read/write handle to {@link #tmpPack} while it is being parsed.
     */
private RandomAccessFile out;

    /** 
     * Length of the original pack stream, before missing bases were appended.
     */
private long origEnd;

    /** 
     * The original checksum of data up to {@link #origEnd}.
     */
private byte[] origHash;

    /** 
     * Current end of the pack file.
     */
private long packEnd;

    /** 
     * Checksum of the entire pack file.
     */
private byte[] packHash;

    /** 
     * Compresses delta bases when completing a thin pack.
     */
private Deflater def;

    /** 
     * The pack that was created, if parsing was successful.
     */
private PackFile newPack;

    ObjectDirectoryPackParser(FileObjectDatabase odb ,InputStream src) {
        super(odb, src);
        this.db = odb;
        this.crc = new CRC32();
        this.tailDigest = Constants.newMessageDigest();
        indexVersion = db.getConfig().get(org.eclipse.jgit.lib.CoreConfig.KEY).getPackIndexVersion();
    }

    /** 
     * * Set the pack index file format version this instance will create.
     * *
     * * @param version
     * *            the version to write. The special version 0 designates the
     * *            oldest (most compatible) format available for the objects.
     * * @see PackIndexWriter
     */
public void setIndexVersion(int version) {
        indexVersion = version;
    }

    /** 
     * * Configure this index pack instance to keep an empty pack.
     * * <p>
     * * By default an empty pack (a pack with no objects) is not kept, as doi so
     * * is completely pointless. With no objects in the pack there is no d stored
     * * by it, so the pack is unnecessary.
     * *
     * * @param empty
     * *            true to enable keeping an empty pack.
     */
public void setKeepEmpty(final boolean empty) {
        keepEmpty = empty;
    }

    /** 
     * * Get the imported {@link PackFile}.
     * * <p>
     * * This method is supplied only to support testing; applications shouldn't
     * * be using it directly to access the imported data.
     * *
     * * @return the imported PackFile, if parsing was successful.
     */
public PackFile getPackFile() {
        return newPack;
    }

    @Override
    public long getPackSize() {
        if ((newPack) == null)
            return super.getPackSize();
        
        File pack = newPack.getPackFile();
        long size = pack.length();
        String p = pack.getAbsolutePath();
        String i = (p.substring(0, ((p.length()) - (".pack".length())))) + ".idx";
        File idx = new File(i);
        if ((idx.exists()) && (idx.isFile()))
            size += idx.length();
        
        return size;
    }

    @Override
    public PackLock parse(ProgressMonitor receiving, ProgressMonitor resolving) throws IOException {
        tmpPack = File.createTempFile("incoming_", ".pack", db.getDirectory());
        tmpIdx = new File(db.getDirectory() , ((ObjectDirectoryPackParser.baseName(tmpPack)) + ".idx"));
        try {
            out = new RandomAccessFile(tmpPack , "rw");
            super.parse(receiving, resolving);
            out.seek(packEnd);
            out.write(packHash);
            out.getChannel().force(true);
            this.out.getChannel().force(true);
            writeIdx();
            tmpPack.setReadOnly();
            tmpIdx.setReadOnly();
            return renameAndOpenPack(getLockMessage());
        } finally {
            if ((def) != null)
                def.end();
            
            try {
                if (((out) != null) && (out.getChannel().isOpen()))
                    out.close();
                
            } catch (IOException closeError) {
            }
            cleanupTemporaryFiles();
        }
    }

    @Override
    protected void onPackHeader(long objectCount) throws IOException {
    }

    @Override
    protected void onBeginWholeObject(long streamPosition, int type, long inflatedSize) throws IOException {
        crc.reset();
    }

    @Override
    protected void onEndWholeObject(PackedObjectInfo info) throws IOException {
        info.setCRC(((int)(crc.getValue())));
    }

    @Override
    protected void onBeginOfsDelta(long streamPosition, long baseStreamPosition, long inflatedSize) throws IOException {
        crc.reset();
    }

    @Override
    protected void onBeginRefDelta(long streamPosition, AnyObjectId baseId, long inflatedSize) throws IOException {
        crc.reset();
    }

    @Override
    protected PackParser.UnresolvedDelta onEndDelta() throws IOException {
        PackParser.UnresolvedDelta delta = new PackParser.UnresolvedDelta();
        delta.setCRC(((int)(crc.getValue())));
        return delta;
    }

    @Override
    protected void onInflatedObjectData(PackedObjectInfo obj, int typeCode, byte[] data) throws IOException {
    }

    @Override
    protected void onObjectHeader(PackParser.Source src, byte[] raw, int pos, int len) throws IOException {
        crc.update(raw, pos, len);
    }

    @Override
    protected void onObjectData(PackParser.Source src, byte[] raw, int pos, int len) throws IOException {
        crc.update(raw, pos, len);
    }

    @Override
    protected void onStoreStream(byte[] raw, int pos, int len) throws IOException {
        out.write(raw, pos, len);
    }

    @Override
    protected void onPackFooter(byte[] hash) throws IOException {
        packEnd = out.getFilePointer();
        origEnd = packEnd;
        origHash = hash;
        packHash = hash;
    }

    @Override
    protected PackParser.ObjectTypeAndSize seekDatabase(PackParser.UnresolvedDelta delta, PackParser.ObjectTypeAndSize info) throws IOException {
        out.seek(delta.getOffset());
        crc.reset();
        return readObjectHeader(info);
    }

    @Override
    protected PackParser.ObjectTypeAndSize seekDatabase(PackedObjectInfo obj, PackParser.ObjectTypeAndSize info) throws IOException {
        out.seek(obj.getOffset());
        crc.reset();
        return readObjectHeader(info);
    }

    @Override
    protected int readDatabase(byte[] dst, int pos, int cnt) throws IOException {
        return out.read(dst, pos, cnt);
    }

    @Override
    protected boolean checkCRC(int oldCRC) {
        return oldCRC == ((int)(crc.getValue()));
    }

    private static String baseName(File tmpPack) {
        String name = tmpPack.getName();
        return name.substring(0, name.lastIndexOf('.'));
    }

    private void cleanupTemporaryFiles() {
        if ((((tmpIdx) != null) && (!(tmpIdx.delete()))) && (tmpIdx.exists()))
            tmpIdx.deleteOnExit();
        
        if ((((tmpPack) != null) && (!(tmpPack.delete()))) && (tmpPack.exists()))
            tmpPack.deleteOnExit();
        
    }

    @Override
    protected boolean onAppendBase(final int typeCode, final byte[] data, final PackedObjectInfo info) throws IOException {
        info.setOffset(packEnd);
        final byte[] buf = buffer();
        int sz = data.length;
        int len = 0;
        buf[len++] = ((byte)((typeCode << 4) | (sz & 15)));
        sz >>>= 4;
        while (sz > 0) {
            buf[(len - 1)] |= 128;
            buf[len++] = ((byte)(sz & 127));
            sz >>>= 7;
        }
        tailDigest.update(buf, 0, len);
        crc.reset();
        crc.update(buf, 0, len);
        out.seek(packEnd);
        out.write(buf, 0, len);
        packEnd += len;
        if ((def) == null)
            def = new Deflater(Deflater.DEFAULT_COMPRESSION , false);
        else
            def.reset();
        
        def.setInput(data);
        def.finish();
        while (!(def.finished())) {
            len = def.deflate(buf);
            tailDigest.update(buf, 0, len);
            crc.update(buf, 0, len);
            out.write(buf, 0, len);
            packEnd += len;
        }
        info.setCRC(((int)(crc.getValue())));
        return true;
    }

    @Override
    protected void onEndThinPack() throws IOException {
        final byte[] tailHash = this.tailDigest.digest();
        final byte[] buf = buffer();
        final MessageDigest origDigest = Constants.newMessageDigest();
        final MessageDigest tailDigest = Constants.newMessageDigest();
        final MessageDigest packDigest = Constants.newMessageDigest();
        long origRemaining = origEnd;
        out.seek(0);
        out.readFully(buf, 0, 12);
        origDigest.update(buf, 0, 12);
        origRemaining -= 12;
        org.eclipse.jgit.util.NB.encodeInt32(buf, 8, getObjectCount());
        out.seek(0);
        out.write(buf, 0, 12);
        packDigest.update(buf, 0, 12);
        for ( ;  ; ) {
            final int n = out.read(buf);
            if (n < 0)
                break;
            
            if (origRemaining != 0) {
                final int origCnt = ((int)(java.lang.Math.min(n, origRemaining)));
                origDigest.update(buf, 0, origCnt);
                origRemaining -= origCnt;
                if (origRemaining == 0)
                    tailDigest.update(buf, origCnt, (n - origCnt));
                
            } else
                tailDigest.update(buf, 0, n);
            
            packDigest.update(buf, 0, n);
        }
        if ((!(java.util.Arrays.equals(origDigest.digest(), origHash))) || (!(java.util.Arrays.equals(tailDigest.digest(), tailHash))))
            throw new IOException(JGitText.get().packCorruptedWhileWritingToFilesystem);
        
        packHash = packDigest.digest();
    }

    private void writeIdx() throws IOException {
        List<org.eclipse.jgit.transport.PackedObjectInfo> list = getSortedObjectList(null);
        final FileOutputStream os = new FileOutputStream(tmpIdx);
        try {
            final PackIndexWriter iw;
            if ((indexVersion) <= 0)
                iw = PackIndexWriter.createOldestPossible(os, list);
            else
                iw = PackIndexWriter.createVersion(os, indexVersion);
            
            iw.write(list, packHash);
            os.getChannel().force(true);
        } finally {
            os.close();
        }
    }

    private PackLock renameAndOpenPack(final String lockMessage) throws IOException {
        if ((!(keepEmpty)) && ((getObjectCount()) == 0)) {
            cleanupTemporaryFiles();
            return null;
        } 
        final MessageDigest d = Constants.newMessageDigest();
        final byte[] oeBytes = new byte[Constants.OBJECT_ID_LENGTH];
        for (int i = 0 ; i < (getObjectCount()) ; i++) {
            final PackedObjectInfo oe = getObject(i);
            oe.copyRawTo(oeBytes, 0);
            d.update(oeBytes);
        }
        final String name = org.eclipse.jgit.lib.ObjectId.fromRaw(d.digest()).name();
        final File packDir = new File(db.getDirectory() , "pack");
        final File finalPack = new File(packDir , (("pack-" + name) + ".pack"));
        final File finalIdx = new File(packDir , (("pack-" + name) + ".idx"));
        final PackLock keep = new PackLock(finalPack , db.getFS());
        if (((!(packDir.exists())) && (!(packDir.mkdir()))) && (!(packDir.exists()))) {
            cleanupTemporaryFiles();
            throw new IOException(java.text.MessageFormat.format(JGitText.get().cannotCreateDirectory, packDir.getAbsolutePath()));
        } 
        if (finalPack.exists()) {
            cleanupTemporaryFiles();
            return null;
        } 
        if (lockMessage != null) {
            try {
                if (!(keep.lock(lockMessage)))
                    throw new LockFailedException(finalPack , java.text.MessageFormat.format(JGitText.get().cannotLockPackIn, finalPack));
                
            } catch (IOException e) {
                cleanupTemporaryFiles();
                throw e;
            }
        } 
        if (!(tmpPack.renameTo(finalPack))) {
            cleanupTemporaryFiles();
            keep.unlock();
            throw new IOException(java.text.MessageFormat.format(JGitText.get().cannotMovePackTo, finalPack));
        } 
        if (!(tmpIdx.renameTo(finalIdx))) {
            cleanupTemporaryFiles();
            keep.unlock();
            if (!(finalPack.delete()))
                finalPack.deleteOnExit();
            
            throw new IOException(java.text.MessageFormat.format(JGitText.get().cannotMoveIndexTo, finalIdx));
        } 
        try {
            newPack = db.openPack(finalPack);
        } catch (IOException err) {
            keep.unlock();
            if (finalPack.exists())
                org.eclipse.jgit.util.FileUtils.delete(finalPack);
            
            if (finalIdx.exists())
                org.eclipse.jgit.util.FileUtils.delete(finalIdx);
            
            throw err;
        }
        return lockMessage != null ? keep : null;
    }
}

