package org.eclipse.jgit.transport;

import java.util.ArrayList;
import java.io.IOException;
import java.io.InputStream;
import org.eclipse.jgit.internal.JGitText;
import java.util.List;
import org.eclipse.jgit.util.io.MessageWriter;
import org.eclipse.jgit.errors.NoRemoteRepositoryException;
import org.eclipse.jgit.errors.NotSupportedException;
import org.eclipse.jgit.lib.Repository;
import java.util.Set;
import org.eclipse.jgit.util.io.StreamCopyThread;
import org.eclipse.jgit.errors.TransportException;

/** 
 * Transport through an SSH tunnel.
 * <p>
 * The SSH transport requires the remote side to have Git installed, as the
 * transport logs into the remote system and executes a Git helper program on
 * the remote side to read (or write) the remote repository's files.
 * <p>
 * This transport does not support direct SCP style of copying files, as it
 * assumes there are Git specific smarts on the remote side to perform object
 * enumeration, save file modification and hook execution.
 */
public class TransportGitSsh extends SshTransport implements PackTransport {
    static final TransportProtocol PROTO_SSH = new TransportProtocol() {
        private final String[] schemeNames = new String[]{ "ssh" , "ssh+git" , "git+ssh" };

        private final Set<java.lang.String> schemeSet = java.util.Collections.unmodifiableSet(new java.util.LinkedHashSet<java.lang.String>(java.util.Arrays.asList(schemeNames)));

        public String getName() {
            return JGitText.get().transportProtoSSH;
        }

        public Set<java.lang.String> getSchemes() {
            return schemeSet;
        }

        public Set<URIishField> getRequiredFields() {
            return java.util.Collections.unmodifiableSet(java.util.EnumSet.of(URIishField.HOST, URIishField.PATH));
        }

        public Set<URIishField> getOptionalFields() {
            return java.util.Collections.unmodifiableSet(java.util.EnumSet.of(URIishField.USER, URIishField.PASS, URIishField.PORT));
        }

        public int getDefaultPort() {
            return 22;
        }

        @Override
        public boolean canHandle(URIish uri, Repository local, String remoteName) {
            if ((uri.getScheme()) == null) {
                return ((((uri.getHost()) != null) && ((uri.getPath()) != null)) && ((uri.getHost().length()) != 0)) && ((uri.getPath().length()) != 0);
            } 
            return super.canHandle(uri, local, remoteName);
        }

        public Transport open(URIish uri, Repository local, String remoteName) throws NotSupportedException {
            return new TransportGitSsh(local , uri);
        }

        @Override
        public Transport open(URIish uri) throws NotSupportedException, TransportException {
            return new TransportGitSsh(uri);
        }
    };

    TransportGitSsh(final Repository local ,final URIish uri) {
        super(local, uri);
        initSshSessionFactory();
    }

    TransportGitSsh(final URIish uri) {
        super(uri);
        initSshSessionFactory();
    }

    private void initSshSessionFactory() {
        if (TransportGitSsh.useExtSession()) {
            setSshSessionFactory(new org.eclipse.jgit.transport.SshSessionFactory() {
                @Override
                public RemoteSession getSession(URIish uri2, org.eclipse.jgit.transport.CredentialsProvider credentialsProvider, org.eclipse.jgit.util.FS fs, int tms) throws TransportException {
                    return new ExtSession();
                }
            });
        } 
    }

    @Override
    public FetchConnection openFetch() throws TransportException {
        return new SshFetchConnection();
    }

    @Override
    public PushConnection openPush() throws TransportException {
        return new SshPushConnection();
    }

    String commandFor(final String exe) {
        String path = uri.getPath();
        if (((uri.getScheme()) != null) && (uri.getPath().startsWith("/~")))
            path = uri.getPath().substring(1);
        
        final StringBuilder cmd = new StringBuilder();
        cmd.deleteCharAt(((cmd.length()) - 1));
        cmd.append(' ');
        cmd.append(org.eclipse.jgit.util.QuotedString.BOURNE.quote(path));
        return cmd.toString();
    }

    void checkExecFailure(int status, String exe, String why) throws TransportException {
        if (status == 127) {
            IOException cause = null;
            if ((why != null) && ((why.length()) > 0))
                cause = new IOException(why);
            
            throw new TransportException(uri , java.text.MessageFormat.format(JGitText.get().cannotExecute, commandFor(exe)) , cause);
        } 
    }

    NoRemoteRepositoryException cleanNotFound(NoRemoteRepositoryException nf, String why) {
        if ((why == null) || ((why.length()) == 0))
            return nf;
        
        String path = uri.getPath();
        if (((uri.getScheme()) != null) && (uri.getPath().startsWith("/~")))
            path = uri.getPath().substring(1);
        
        final StringBuilder pfx = new StringBuilder();
        pfx.append("fatal: ");
        pfx.append(org.eclipse.jgit.util.QuotedString.BOURNE.quote(path));
        pfx.append(": ");
        if (why.startsWith(pfx.toString()))
            why = why.substring(pfx.length());
        
        return new NoRemoteRepositoryException(uri , why);
    }

    private static boolean useExtSession() {
        return (org.eclipse.jgit.util.SystemReader.getInstance().getenv("GIT_SSH")) != null;
    }

    private class ExtSession implements RemoteSession {
        public Process exec(String command, int timeout) throws TransportException {
            String ssh = org.eclipse.jgit.util.SystemReader.getInstance().getenv("GIT_SSH");
            boolean putty = ssh.toLowerCase().contains("plink");
            List<java.lang.String> args = new ArrayList<java.lang.String>();
            args.add(ssh);
            if (putty && (!(ssh.toLowerCase().contains("tortoiseplink"))))
                args.add("-batch");
            
            if (0 < (getURI().getPort())) {
                args.add((putty ? "-P" : "-p"));
                args.add(String.valueOf(getURI().getPort()));
            } 
            if ((getURI().getUser()) != null)
                args.add((((getURI().getUser()) + "@") + (getURI().getHost())));
            else
                args.add(getURI().getHost());
            
            args.add(command);
            ProcessBuilder pb = new ProcessBuilder();
            pb.command(args);
            if ((local.getDirectory()) != null)
                pb.environment().put(org.eclipse.jgit.lib.Constants.GIT_DIR_KEY, local.getDirectory().getPath());
            
            try {
                return pb.start();
            } catch (IOException err) {
                throw new TransportException(err.getMessage() , err);
            }
        }

        public void disconnect() {
        }
    }

    class SshFetchConnection extends BasePackFetchConnection {
        private final Process process;

        private StreamCopyThread errorThread;

        SshFetchConnection() throws TransportException {
            super(org.eclipse.jgit.transport.TransportGitSsh.this);
            try {
                process = getSession().exec(commandFor(getOptionUploadPack()), getTimeout());
                final MessageWriter msg = new MessageWriter();
                setMessageWriter(msg);
                final InputStream upErr = process.getErrorStream();
                errorThread = new StreamCopyThread(upErr , msg.getRawStream());
                errorThread.start();
                init(process.getInputStream(), process.getOutputStream());
            } catch (TransportException err) {
                close();
                throw err;
            } catch (IOException err) {
                close();
                throw new TransportException(uri , JGitText.get().remoteHungUpUnexpectedly , err);
            }
            try {
                readAdvertisedRefs();
            } catch (NoRemoteRepositoryException notFound) {
                final String msgs = getMessages();
                checkExecFailure(process.exitValue(), getOptionUploadPack(), msgs);
                throw cleanNotFound(notFound, msgs);
            }
        }

        @Override
        public void close() {
            endOut();
            if ((errorThread) != null) {
                try {
                    errorThread.halt();
                } catch (InterruptedException e) {
                } finally {
                    errorThread = null;
                }
            } 
            super.close();
            if ((process) != null)
                process.destroy();
            
        }
    }

    class SshPushConnection extends BasePackPushConnection {
        private final Process process;

        private StreamCopyThread errorThread;

        SshPushConnection() throws TransportException {
            super(org.eclipse.jgit.transport.TransportGitSsh.this);
            try {
                process = getSession().exec(commandFor(getOptionReceivePack()), getTimeout());
                final MessageWriter msg = new MessageWriter();
                setMessageWriter(msg);
                final InputStream rpErr = process.getErrorStream();
                errorThread = new StreamCopyThread(rpErr , msg.getRawStream());
                errorThread.start();
                init(process.getInputStream(), process.getOutputStream());
            } catch (TransportException err) {
                close();
                throw err;
            } catch (IOException err) {
                close();
                throw new TransportException(uri , JGitText.get().remoteHungUpUnexpectedly , err);
            }
            try {
                readAdvertisedRefs();
            } catch (NoRemoteRepositoryException notFound) {
                final String msgs = getMessages();
                checkExecFailure(process.exitValue(), getOptionReceivePack(), msgs);
                throw cleanNotFound(notFound, msgs);
            }
        }

        @Override
        public void close() {
            endOut();
            if ((errorThread) != null) {
                try {
                    errorThread.halt();
                } catch (InterruptedException e) {
                } finally {
                    errorThread = null;
                }
            } 
            super.close();
            if ((process) != null)
                process.destroy();
            
        }
    }
}

