package org.eclipse.jgit.api;

import org.eclipse.jgit.treewalk.AbstractTreeIterator;
import org.eclipse.jgit.treewalk.CanonicalTreeParser;
import org.eclipse.jgit.api.errors.CheckoutConflictException;
import java.util.Collection;
import org.eclipse.jgit.lib.Constants;
import org.eclipse.jgit.dircache.DirCache;
import org.eclipse.jgit.dircache.DirCacheBuilder;
import org.eclipse.jgit.dircache.DirCacheCheckout;
import org.eclipse.jgit.dircache.DirCacheEntry;
import org.eclipse.jgit.dircache.DirCacheIterator;
import org.eclipse.jgit.api.errors.GitAPIException;
import java.io.IOException;
import org.eclipse.jgit.api.errors.JGitInternalException;
import org.eclipse.jgit.internal.JGitText;
import java.util.LinkedList;
import org.eclipse.jgit.lib.ObjectId;
import org.eclipse.jgit.lib.Ref;
import org.eclipse.jgit.lib.RefUpdate;
import org.eclipse.jgit.lib.Repository;
import org.eclipse.jgit.lib.RepositoryState;
import org.eclipse.jgit.revwalk.RevCommit;
import org.eclipse.jgit.revwalk.RevWalk;
import org.eclipse.jgit.treewalk.TreeWalk;

/** 
 * A class used to execute a {@code Reset} command. It has setters for all
 * supported options and arguments of this command and a {@link #call()} method
 * to finally execute the command. Each instance of this class should only be
 * used for one invocation of the command (means: one call to {@link #call()})
 * 
 * @see <a href="http://www.kernel.org/pub/software/scm/git/docs/git-reset.html"
 * >Git documentation about Reset</a>
 */
public class ResetCommand extends GitCommand<org.eclipse.jgit.lib.Ref> {
    /** 
     * * Kind of reset
     */
public enum ResetType {
SOFT, MIXED, HARD, MERGE, KEEP;    }

    private String ref = null;

    private ResetType mode;

    private Collection<java.lang.String> filepaths = new LinkedList<java.lang.String>();

    /** 
     * *
     * * @param repo
     */
public ResetCommand(Repository repo) {
        super(repo);
    }

    /** 
     * * Executes the {@code Reset} command. Each instance of this class should
     * * only be used for one invocation of the command. Don't call this method
     * * twice on an instance.
     * *
     * * @return the Ref after reset
     * * @throws GitAPIException
     */
public Ref call() throws CheckoutConflictException, GitAPIException {
        checkCallable();
        try {
            RepositoryState state = repo.getRepositoryState();
            final boolean merging = (state.equals(RepositoryState.MERGING)) || (state.equals(RepositoryState.MERGING_RESOLVED));
            final boolean cherryPicking = (state.equals(RepositoryState.CHERRY_PICKING)) || (state.equals(RepositoryState.CHERRY_PICKING_RESOLVED));
            final boolean reverting = (state.equals(RepositoryState.REVERTING)) || (state.equals(RepositoryState.REVERTING_RESOLVED));
            final ObjectId commitId = resolveRefToCommitId();
            if (((ref) != null) && (commitId == null)) {
                throw new JGitInternalException((("Invalid ref " + (ref)) + " specified"));
            } 
            final ObjectId commitTree;
            if (commitId != null)
                commitTree = parseCommit(commitId).getTree();
            else
                commitTree = null;
            
            if (!(filepaths.isEmpty())) {
                resetIndexForPaths(commitTree);
                setCallable(false);
                return repo.getRef(Constants.HEAD);
            } 
            final Ref result;
            if (commitId != null) {
                final RefUpdate ru = repo.updateRef(Constants.HEAD);
                ru.setNewObjectId(commitId);
                String refName = Repository.shortenRefName(getRefOrHEAD());
                String message = (refName + ": updating ") + (Constants.HEAD);
                ru.setRefLogMessage(message, false);
                if ((ru.forceUpdate()) == (RefUpdate.Result.LOCK_FAILURE))
                    throw new JGitInternalException(java.text.MessageFormat.format(JGitText.get().cannotLock, ru.getName()));
                
                ObjectId origHead = ru.getOldObjectId();
                if (origHead != null)
                    repo.writeOrigHead(origHead);
                
                result = ru.getRef();
            } else {
                result = repo.getRef(Constants.HEAD);
            }
            if ((mode) == null)
                mode = ResetType.MIXED;
            
            switch (mode) {
                case HARD :
                    checkoutIndex(commitTree);
                    break;
                case MIXED :
                    resetIndex(commitTree);
                    break;
                case SOFT :
                    break;
                case KEEP :
                case MERGE :
                    throw new UnsupportedOperationException();
            }
            if ((mode) != (ResetType.SOFT)) {
                if (merging)
                    resetMerge();
                else if (cherryPicking)
                    resetCherryPick();
                else if (reverting)
                    resetRevert();
                else if ((repo.readSquashCommitMsg()) != null)
                    repo.writeSquashCommitMsg(null);
                
            } 
            setCallable(false);
            return result;
        } catch (IOException e) {
            throw new JGitInternalException(JGitText.get().exceptionCaughtDuringExecutionOfResetCommand , e);
        }
    }

    private RevCommit parseCommit(final ObjectId commitId) {
        RevCommit commit;
        RevWalk rw = new RevWalk(repo);
        try {
            commit = rw.parseCommit(commitId);
        } catch (IOException e) {
            throw new JGitInternalException(java.text.MessageFormat.format(JGitText.get().cannotReadCommit, commitId.toString()) , e);
        } finally {
            rw.release();
        }
        return commit;
    }

    private ObjectId resolveRefToCommitId() {
        try {
            return repo.resolve(((getRefOrHEAD()) + "^{commit}"));
        } catch (IOException e) {
            throw new JGitInternalException(java.text.MessageFormat.format(JGitText.get().cannotRead, getRefOrHEAD()) , e);
        }
    }

    /** 
     * * @param ref
     * *            the ref to reset to, defaults to HEAD if not specified
     * * @return this instance
     */
public ResetCommand setRef(String ref) {
        this.ref = ref;
        return this;
    }

    /** 
     * * @param mode
     * *            the mode of the reset command
     * * @return this instance
     */
public ResetCommand setMode(ResetType mode) {
        if (!(filepaths.isEmpty()))
            throw new JGitInternalException(java.text.MessageFormat.format(JGitText.get().illegalCombinationOfArguments, "[--mixed | --soft | --hard]", "<paths>..."));
        
        this.mode = mode;
        return this;
    }

    /** 
     * * @param path
     * *            repository-relative path of file/directory to reset (with
     * *            <code>/</code> as separator)
     * * @return this instance
     */
public ResetCommand addPath(String path) {
        if ((mode) != null)
            throw new JGitInternalException(java.text.MessageFormat.format(JGitText.get().illegalCombinationOfArguments, "<paths>...", "[--mixed | --soft | --hard]"));
        
        filepaths.add(path);
        return this;
    }

    private String getRefOrHEAD() {
        if ((ref) != null)
            return ref;
        else
            return Constants.HEAD;
        
    }

    private void resetIndexForPaths(ObjectId commitTree) {
        DirCache dc = null;
        try {
            dc = repo.lockDirCache();
            DirCacheBuilder builder = dc.builder();
            final TreeWalk tw = new TreeWalk(repo);
            tw.addTree(new org.eclipse.jgit.dircache.DirCacheBuildIterator(builder));
            if (commitTree != null)
                tw.addTree(commitTree);
            else
                tw.addTree(new org.eclipse.jgit.treewalk.EmptyTreeIterator());
            
            tw.setFilter(org.eclipse.jgit.treewalk.filter.PathFilterGroup.createFromStrings(filepaths));
            tw.setRecursive(true);
            while (tw.next()) {
                final CanonicalTreeParser tree = tw.getTree(1, CanonicalTreeParser.class);
                if (tree != null) {
                    DirCacheEntry entry = new DirCacheEntry(tw.getRawPath());
                    entry.setFileMode(tree.getEntryFileMode());
                    entry.setObjectId(tree.getEntryObjectId());
                    builder.add(entry);
                } 
            }
            builder.commit();
        } catch (IOException e) {
            throw new RuntimeException(e);
        } finally {
            if (dc != null)
                dc.unlock();
            
        }
    }

    private void resetIndex(ObjectId commitTree) throws IOException {
        DirCache dc = repo.lockDirCache();
        TreeWalk walk = null;
        try {
            DirCacheBuilder builder = dc.builder();
            walk = new TreeWalk(repo);
            if (commitTree != null)
                walk.addTree(commitTree);
            else
                walk.addTree(new org.eclipse.jgit.treewalk.EmptyTreeIterator());
            
            walk.addTree(new DirCacheIterator(dc));
            walk.setRecursive(true);
            while (walk.next()) {
                AbstractTreeIterator cIter = walk.getTree(0, AbstractTreeIterator.class);
                if (cIter == null) {
                    continue;
                } 
                final DirCacheEntry entry = new DirCacheEntry(walk.getRawPath());
                entry.setFileMode(cIter.getEntryFileMode());
                entry.setObjectIdFromRaw(cIter.idBuffer(), cIter.idOffset());
                DirCacheIterator dcIter = walk.getTree(1, DirCacheIterator.class);
                if ((dcIter != null) && (dcIter.idEqual(cIter))) {
                    DirCacheEntry indexEntry = dcIter.getDirCacheEntry();
                    entry.setLastModified(indexEntry.getLastModified());
                    entry.setLength(indexEntry.getLength());
                } 
                builder.add(entry);
            }
            builder.commit();
        } finally {
            dc.unlock();
            if (walk != null)
                walk.release();
            
        }
    }

    private void checkoutIndex(ObjectId commitTree) throws IOException, GitAPIException {
        DirCache dc = repo.lockDirCache();
        try {
            DirCacheCheckout checkout = new DirCacheCheckout(repo , dc , commitTree);
            checkout.setFailOnConflict(false);
            try {
                checkout.checkout();
            } catch (org.eclipse.jgit.errors.CheckoutConflictException cce) {
                throw new CheckoutConflictException(checkout.getConflicts() , cce);
            }
        } finally {
            dc.unlock();
        }
    }

    private void resetMerge() throws IOException {
        repo.writeMergeHeads(null);
        repo.writeMergeCommitMsg(null);
    }

    private void resetCherryPick() throws IOException {
        repo.writeCherryPickHead(null);
        repo.writeMergeCommitMsg(null);
    }

    private void resetRevert() throws IOException {
        repo.writeRevertHead(null);
        if (true) {
            repo.writeMergeCommitMsg(null);
            this.repo.getRefDatabase().close();
        } 
    }
}

