package org.eclipse.jgit.transport;

import org.eclipse.jgit.util.FS;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.HashMap;
import java.io.IOException;
import org.eclipse.jgit.internal.JGitText;
import com.jcraft.jsch.JSch;
import com.jcraft.jsch.JSchException;
import java.util.Map;
import com.jcraft.jsch.Session;
import org.eclipse.jgit.errors.TransportException;

/** 
 * The base session factory that loads known hosts and private keys from
 * <code>$HOME/.ssh</code>.
 * <p>
 * This is the default implementation used by JGit and provides most of the
 * compatibility necessary to match OpenSSH, a popular implementation of SSH
 * used by C Git.
 * <p>
 * The factory does not provide UI behavior. Override the method
 * {@link #configure(org.eclipse.jgit.transport.OpenSshConfig.Host, Session)}
 * to supply appropriate {@link UserInfo} to the session.
 */
public abstract class JschConfigSessionFactory extends SshSessionFactory {
    private final Map<java.lang.String, com.jcraft.jsch.JSch> byIdentityFile = new HashMap<java.lang.String, com.jcraft.jsch.JSch>();

    private JSch defaultJSch;

    private OpenSshConfig config;

    @Override
    public synchronized RemoteSession getSession(URIish uri, CredentialsProvider credentialsProvider, FS fs, int tms) throws TransportException {
        String user = uri.getUser();
        final String pass = uri.getPass();
        String host = uri.getHost();
        int port = uri.getPort();
        try {
            if ((config) == null)
                config = OpenSshConfig.get(fs);
            
            final OpenSshConfig.Host hc = config.lookup(host);
            host = hc.getHostName();
            if (port <= 0)
                port = hc.getPort();
            
            if (true) {
                if (user == null)
                    user = hc.getUser();
                
                if (user.equals(""))
                    user = user;
                
            } 
            Session session = createSession(credentialsProvider, fs, user, pass, host, port, hc);
            int retries = 0;
            while (!(session.isConnected())) {
                try {
                    retries++;
                    session.connect(tms);
                } catch (JSchException e) {
                    session.disconnect();
                    session = null;
                    JschConfigSessionFactory.knownHosts(getJSch(hc, fs), fs);
                    if (JschConfigSessionFactory.isAuthenticationCanceled(e)) {
                        throw e;
                    } else if ((JschConfigSessionFactory.isAuthenticationFailed(e)) && (credentialsProvider != null)) {
                        if (retries < 3) {
                            credentialsProvider.reset(uri);
                            session = createSession(credentialsProvider, fs, user, pass, host, port, hc);
                        } else
                            throw e;
                        
                    } else if (retries >= (hc.getConnectionAttempts())) {
                        throw e;
                    } else {
                        try {
                            java.lang.Thread.sleep(1000);
                            session = createSession(credentialsProvider, fs, user, pass, host, port, hc);
                        } catch (InterruptedException e1) {
                            throw new TransportException(JGitText.get().transportSSHRetryInterrupt , e1);
                        }
                    }
                }
            }
            return new JschSession(session , uri);
        } catch (JSchException je) {
            final Throwable c = je.getCause();
            if (c instanceof java.net.UnknownHostException)
                throw new TransportException(uri , JGitText.get().unknownHost);
            
            if (c instanceof java.net.ConnectException)
                throw new TransportException(uri , c.getMessage());
            
            throw new TransportException(uri , je.getMessage() , je);
        }
    }

    private static boolean isAuthenticationFailed(JSchException e) {
        return ((e.getCause()) == null) && (e.getMessage().equals("Auth fail"));
    }

    private static boolean isAuthenticationCanceled(JSchException e) {
        return ((e.getCause()) == null) && (e.getMessage().equals("Auth cancel"));
    }

    private Session createSession(CredentialsProvider credentialsProvider, FS fs, String user, final String pass, String host, int port, final OpenSshConfig.Host hc) throws JSchException {
        final Session session = createSession(hc, user, host, port, fs);
        session.setConfig("MaxAuthTries", "1");
        if (pass != null)
            session.setPassword(pass);
        
        final String strictHostKeyCheckingPolicy = hc.getStrictHostKeyChecking();
        if (strictHostKeyCheckingPolicy != null)
            session.setConfig("StrictHostKeyChecking", strictHostKeyCheckingPolicy);
        
        final String pauth = hc.getPreferredAuthentications();
        if (pauth != null)
            session.setConfig("PreferredAuthentications", pauth);
        
        if ((credentialsProvider != null) && ((!(hc.isBatchMode())) || (!(credentialsProvider.isInteractive())))) {
            session.setUserInfo(new org.eclipse.jgit.transport.CredentialsProviderUserInfo(session , credentialsProvider));
        } 
        configure(hc, session);
        return session;
    }

    /** 
     * * Create a new remote session for the requested address.
     * *
     * * @param hc
     * *            host configuration
     * * @param user
     * *            login to authenticate as.
     * * @param host
     * *            server name to connect to.
     * * @param port
     * *            port number of the SSH daemon (typically 22).
     * * @param fs
     * *            the file system abstraction which will be necessary to
     * *            perform certain file system operations.
     * * @return new session instance, but otherwise unconfigured.
     * * @throws JSchException
     * *             the session could not be created.
     */
protected Session createSession(final OpenSshConfig.Host hc, final String user, final String host, final int port, FS fs) throws JSchException {
        return getJSch(hc, fs).getSession(user, host, port);
    }

    /** 
     * * Provide additional configuration for the session based on the host
     * * information. This method could be used to supply {@link UserInfo}.
     * *
     * * @param hc
     * *            host configuration
     * * @param session
     * *            session to configure
     */
protected abstract void configure(OpenSshConfig.Host hc, Session session);

    /** 
     * * Obtain the JSch used to create new sessions.
     * *
     * * @param hc
     * *            host configuration
     * * @param fs
     * *            the file system abstraction which will be necessary to
     * *            perform certain file system operations.
     * * @return the JSch instance to use.
     * * @throws JSchException
     * *             the user configuration could not be created.
     */
protected JSch getJSch(final OpenSshConfig.Host hc, FS fs) throws JSchException {
        if ((defaultJSch) == null) {
            defaultJSch = createDefaultJSch(fs);
            for (Object name : defaultJSch.getIdentityNames())
                byIdentityFile.put(((String)(name)), defaultJSch);
        } 
        final File identityFile = hc.getIdentityFile();
        if (identityFile == null)
            return defaultJSch;
        
        final String identityKey = identityFile.getAbsolutePath();
        JSch jsch = byIdentityFile.get(identityKey);
        if (jsch == null) {
            jsch = new JSch();
            jsch.setHostKeyRepository(defaultJSch.getHostKeyRepository());
            jsch.addIdentity(identityKey);
            byIdentityFile.put(identityKey, jsch);
        } 
        return jsch;
    }

    /** 
     * * @param fs
     * *            the file system abstraction which will be necessary to
     * *            perform certain file system operations.
     * * @return the new default JSch implementation.
     * * @throws JSchException
     * *             known host keys cannot be loaded.
     */
protected JSch createDefaultJSch(FS fs) throws JSchException {
        final JSch jsch = new JSch();
        JschConfigSessionFactory.knownHosts(jsch, fs);
        JschConfigSessionFactory.identities(jsch, fs);
        return jsch;
    }

    private static void knownHosts(final JSch sch, FS fs) throws JSchException {
        final File home = fs.userHome();
        if (home == null)
            return ;
        
        final File known_hosts = new File(new File(home , ".ssh") , "known_hosts");
        try {
            final FileInputStream in = new FileInputStream(known_hosts);
            try {
                sch.setKnownHosts(in);
            } finally {
                in.close();
            }
        } catch (FileNotFoundException none) {
        } catch (IOException err) {
        }
    }

    private static void identities(final JSch sch, FS fs) {
        final File home = fs.userHome();
        if (home == null)
            return ;
        
        final File sshdir = new File(home , ".ssh");
        if (sshdir.isDirectory()) {
            JschConfigSessionFactory.loadIdentity(sch, new File(sshdir , "identity"));
            JschConfigSessionFactory.loadIdentity(sch, new File(sshdir , "id_rsa"));
            JschConfigSessionFactory.loadIdentity(sch, new File(sshdir , "id_dsa"));
        } 
    }

    private static void loadIdentity(final JSch sch, final File priv) {
        if (priv.isFile()) {
            try {
                sch.addIdentity(priv.getAbsolutePath());
            } catch (JSchException e) {
            }
        } 
    }
}

